Index: include/core/SkImage.h |
diff --git a/include/core/SkImage.h b/include/core/SkImage.h |
index e0ea7217d0773248d95d1ce2eabf4e6af3c9c820..28b1803629318cacec31a3aa92a5c3dd2bd1d23e 100644 |
--- a/include/core/SkImage.h |
+++ b/include/core/SkImage.h |
@@ -171,11 +171,11 @@ public: |
bool isTextureBacked() const; |
/** |
* Retrieves the backend API handle of the texture. If flushPendingGrContextReads then the |
* GrContext will issue to the backend API any deferred read operations on the texture before |
* returning. |
*/ |
- GrBackendObject getTextureHandle(bool flushPendingGrContextReads) const; |
+ GrBackendObject getTextureHandle(bool flushPendingGrContextIO) const; |
/** |
* Copy the pixels from the image into the specified buffer (pixels + rowBytes), |
@@ -171,11 +171,11 @@ public: |
bool isTextureBacked() const; |
/** |
- * Retrieves the backend API handle of the texture. If flushPendingGrContextReads then the |
- * GrContext will issue to the backend API any deferred read operations on the texture before |
+ * Retrieves the backend API handle of the texture. If flushPendingGrContextIO then the |
+ * GrContext will issue to the backend API any deferred IO operations on the texture before |
* returning. |
*/ |